<?php
/**
 * Revolution Lightbox PACKAGED v2.0
 * Main class.
 *
 * @author Tibi - FWDesign [https://webdesign-flash.ro/]
 * Copyright © 2006 All Rights Reserved.
 */

class FWDRL{
	

	const MIN_WP_VER =  "3.5.0";
	const VERSION = '2.1';
	const CAPABILITY = "edit_fwdrl";
	private $_data;
	private $_dir_url;
	private $is_Ligtbox_initialized = false;


    // Initialize.
    public function init(){
		$this->_dir_url = plugin_dir_url(dirname(__FILE__));
	
    	// Set hooks.
    	add_action("admin_menu", array($this, "add_plugin_menu"));
    	add_action('admin_enqueue_scripts', array($this, "enqueue_admin_files"));
		add_action("wp_enqueue_scripts", array($this, "add_header_files"));
		add_shortcode("fwdrl", array($this, "set_rl"));
		
		// Set data.
		$this->_data = new FWDRLData();
		$this->_data->init();

		// Make plugin available for translation.
		load_plugin_textdomain('fwdrl', false, basename(realpath(__DIR__ . '/..')) . '/languages/');
    }

	
    // Add plugin menu and shortcode metabox.
    public function add_plugin_menu(){
		
    	// add menus
        add_menu_page("Revolution Lightbox", "Revolution Lightbox", FWDRL::CAPABILITY, "fwdrlmenu-general-settings", array($this, "set_general_settings"), esc_url_raw($this->_dir_url) . "content/icons/menu-icon.png");
		add_submenu_page("fwdrlmenu-general-settings", esc_html__('General Settings', 'fwdrl'), esc_html__('General Settings', 'fwdrl'), FWDRL::CAPABILITY, "fwdrlmenu-general-settings");
		add_submenu_page("fwdrlmenu-general-settings", esc_html__('Galleries Manager', 'fwdrl'), esc_html__('Galleries Manager', 'fwdrl'), FWDRL::CAPABILITY, "fwdrlmenu-playlists-manager", array($this, "set_playlists_manager"));
		add_submenu_page("fwdrlmenu-general-settings", esc_html__('CSS Editor', 'fwdrl'), esc_html__('CSS Editor', 'fwdrl'), FWDRL::CAPABILITY, "fwdrlmenu-css-editor", array($this, "set_css_editor"));
    
       	// Add shortcode metabox.
       	$post_type_screens = array("post", "page");
       	$args = array(
	       'public'   => true,
	       '_builtin' => false,
	    );
       	$custom_post_types = get_post_types($args);
       	foreach($custom_post_types as $screen){
       		$post_type_screens[] = $screen;
       	}

    	foreach ($post_type_screens as $screen){
       		add_meta_box("fwdrl-shortcode-generator", "Revolution Lightbox",  array($this, "set_custom_meta_box"), $screen, "side", "default");
    	}
    }


    // Add backend files.
    public function enqueue_admin_files($hook){

    	// General settings.
    	if($hook == 'toplevel_page_fwdrlmenu-general-settings'){
			wp_enqueue_style("fwdrl_fwd_ui_css", esc_url_raw($this->_dir_url) . "css/fwd_ui.css", array(), '1.10.4');
			wp_enqueue_style("fwdrl_general_settings", esc_url_raw($this->_dir_url) . "css/general_settings.css", array(), '1.10.4');
			wp_enqueue_script("fwdrl_fwdtooltip", esc_url_raw($this->_dir_url) . "js/fwdtooltip.js", array(), '1.0');
			wp_enqueue_script("jquery-ui-tabs");
	    	wp_enqueue_style("fwdrl_spectrum_css", esc_url_raw($this->_dir_url) . "css/spectrum.css");
	    	wp_enqueue_script("fwdrl_spectrum_script", esc_url_raw($this->_dir_url) . "js/spectrum.js");
			wp_enqueue_media();
			wp_enqueue_script("fwdrl_general_settings_script", esc_url_raw($this->_dir_url) . "js/general_settings.js", array(), FWDRL::VERSION, true);

		// Galleries manager.
    	}else if($hook == 'revolution-lightbox_page_fwdrlmenu-playlists-manager'){
    		wp_enqueue_style("fwdrl_fwd_ui_css", esc_url_raw($this->_dir_url) . "css/fwd_ui.css", array(), '1.10.4');
    		wp_enqueue_style("fwdrl_playlist_manager", esc_url_raw($this->_dir_url) . "css/playlist_manager.css", array(), FWDRL::VERSION);
			wp_enqueue_script("fwdrl_fwdtooltip", esc_url_raw($this->_dir_url) . "js/fwdtooltip.js", array(), '1.0');
			wp_enqueue_script("jquery-ui-sortable");
			wp_enqueue_script("jquery-ui-accordion");
			wp_enqueue_script("jquery-ui-dialog");
			wp_enqueue_media();
			wp_enqueue_script("fwdrl_playlist_manager_script", esc_url_raw($this->_dir_url) . "js/playlist_manager.js", array(), FWDRL::VERSION, true);

		// CSS editor.
    	}else if($hook == 'revolution-lightbox_page_fwdrlmenu-css-editor'){
    		wp_enqueue_style("fwdrl_fwd_ui_css", esc_url_raw($this->_dir_url) . "css/fwd_ui.css", array(), '1.10.4');
    		wp_enqueue_style("fwdrl_css_editor", esc_url_raw($this->_dir_url) . "css/css_editor.css", array(), FWDRL::VERSION);
    		wp_enqueue_script("fwdrl_css_editor", esc_url_raw($this->_dir_url) . "js/css_editor.js", array(), FWDRL::VERSION, false);

    	// Shortcode.
    	}else if($hook == 'post.php' || $hook == 'post-new.php'){
    		wp_enqueue_style("fwdrl_schortcode", esc_url_raw($this->_dir_url) . "css/shortcode.css", array(), FWDRL::VERSION);
    		wp_enqueue_script("fwdrl_shortcode_script", esc_url_raw($this->_dir_url) . "js/shortcode.js", array(), FWDRL::VERSION, true);
    	}
    }
	

	// Add RL js and css file in the front.
	public function add_header_files(){
		global $post, $wpdb;
		if(empty($post)) return;
     
		$shortcode_found = false;
       	if(has_shortcode($post->post_content, 'fwdrl')){
          	$shortcode_found = true;
       	}else if(isset($post->ID)){ 
          	$result = $wpdb->get_var($wpdb->prepare(
            "SELECT count(*) FROM $wpdb->postmeta " .
            "WHERE post_id = %d and meta_value LIKE '%%fwdrl%%'", $post->ID));
          	$shortcode_found = !empty($result);
       	}

        // Uncomment this to add the front required js/css files only if the shortcode is found in the page/post.
		//if (!empty($shortcode_found)){
			
			wp_enqueue_style("fwdrl", esc_url_raw($this->_dir_url) . "css/fwdrl.css", array(), FWDRL::VERSION);
			wp_enqueue_script("fwdrl", esc_url_raw($this->_dir_url) . "js/FWDRL.js", array(), FWDRL::VERSION, true);
		//}
    }
    

    // Check WP version.
	private function check_wp_ver(){
	    global $wp_version;
	    
		$exit_msg = "The Revolution Lightbox plugin requires WordPress " . esc_html(FWDRL::MIN_WP_VER) . " or newer. <a href='http://codex.wordpress.org/Updating_WordPress'>Please update!</a>";
		
		if (version_compare($wp_version, FWDRL::MIN_WP_VER) <= 0){
			echo $exit_msg;
			return false;
		}
		return true;
	}


	// Update general settings.
    public function set_general_settings(){
    	if (!$this->check_wp_ver()){
    		return;
    	}
    	
    	$msg = "";
		$tab_init_id = 0;
		$toolTipImgSrc = esc_url_raw($this->_dir_url) . "content/icons/help-icon.png"; 
    	
	    if (!empty($_POST) && check_admin_referer("fwdrl_general_settings_update", "fwdrl_general_settings_nonce")){
			$data_obj = json_decode(str_replace("\\", "", $_POST["settings_data"]), true);
			
			$action = $data_obj["action"];
			$settingsAr = $data_obj["settings_ar"];
			$id = 0;

			// Sanitize input.
			foreach($settingsAr as $key => $value) {	

				if($id == 0){
					if(!empty($settingsAr[$key]["mediaSelector"])){
						$settingsAr[$key]["mediaSelector"] = sanitize_text_field($settingsAr[$key]["mediaSelector"]);
					}

					if(!empty($settingsAr[$key]["slideShowDelay"])){
						$settingsAr[$key]["slideShowDelay"] = sanitize_text_field($settingsAr[$key]["slideShowDelay"]);
					}

					if(!empty($settingsAr[$key]["shareButtons"])){
						$settingsAr[$key]["shareButtons"] = sanitize_text_field($settingsAr[$key]["shareButtons"]);
					}

					if(!empty($settingsAr[$key]["shareText"])){
						$settingsAr[$key]["shareText"] = sanitize_text_field($settingsAr[$key]["shareText"]);
					}

					if(!empty($settingsAr[$key]["volume"])){
						$settingsAr[$key]["volume"] = sanitize_text_field($settingsAr[$key]["volume"]);
					}

					if(!empty($settingsAr[$key]["videoAutoPlayText"])){
						$settingsAr[$key]["videoAutoPlayText"] = sanitize_text_field($settingsAr[$key]["videoAutoPlayText"]);
					}
					
					if(!empty($settingsAr[$key]["logoPath"])){
						$settingsAr[$key]["logoPath"] = esc_url_raw($settingsAr[$key]["logoPath"]);
					}

					if(!empty($settingsAr[$key]["logoLink"])){
						$settingsAr[$key]["logoLink"] = esc_url_raw($settingsAr[$key]["logoLink"]);
					}

					if(!empty($settingsAr[$key]["thumbnailsPreviewWidth"])){
						$settingsAr[$key]["thumbnailsPreviewWidth"] = sanitize_text_field($settingsAr[$key]["thumbnailsPreviewWidth"]);
					}

					if(!empty($settingsAr[$key]["skipToVideoText"])){
						$settingsAr[$key]["skipToVideoText"] = sanitize_text_field($settingsAr[$key]["skipToVideoText"]);
					}

					if(!empty($settingsAr[$key]["skipToVideoButtonText"])){
						$settingsAr[$key]["skipToVideoButtonText"] = sanitize_text_field($settingsAr[$key]["skipToVideoButtonText"]);
					}
				}

				$id ++;
			}
			
			$this->_data->settings_ar = $settingsAr;
			$this->_data->set_data();
			
			switch ($action){
			    case "update":
			        $msg = esc_html__('The settings have been updated!', 'fwdrl');
					$tab_init_id = esc_html($data_obj["tab_init_id"]);
			        break;
			    case "reset":
			        $msg = esc_html__('The settings have been reseted to default!', 'fwdrl');
					$tab_init_id = esc_html($data_obj["tab_init_id"]);
			        break;
			}
		}
		
        // Add and escape required js vars.
        $vars = 'var fwdrlSettingsAr = ' . '"' . esc_html(htmlspecialchars(json_encode($this->_data->settings_ar))) . '";';
        $vars .= 'var fwdrlTabInitId = ' .  esc_html($tab_init_id) .';';
		wp_add_inline_script('fwdrl_general_settings_script', $vars);

    	include_once "general_settings.php";
    }
    

    // Galleries settings.
 	public function set_playlists_manager(){

    	if (!$this->check_wp_ver()){
    		return;
    	}
    	
    	$msg = "";
    	$toolTipImgSrc = esc_url_raw($this->_dir_url) . "content/icons/help-icon.png"; 
    	$iconsPath = esc_url_raw($this->_dir_url) . "content/icons/";
    	
	    if (!empty($_POST) && check_admin_referer("fwdrl_playlist_manager_update", "fwdrl_playlist_manager_nonce")){
			$mainPlaylistsAr = json_decode(str_replace("\\", "", $_POST["playlist_data"]), true);
			
			// Sanitize input.
			foreach($mainPlaylistsAr as $pid => $playlist) {	
				$mainPlaylistsAr[$pid]["name"] = sanitize_text_field($this->clean_name($mainPlaylistsAr[$pid]["name"]));

				foreach($playlist["items"] as $tid => $items){
					$playlist["items"][$tid]["name"] = sanitize_text_field($this->clean_name_2($playlist["items"][$tid]["name"]));
					$playlist["items"][$tid]["source"] = sanitize_text_field($playlist["items"][$tid]["source"]);

					if(isset($playlist["items"][$tid]["max_width"]) && strlen($playlist["items"][$tid]["max_width"]) >= 1){
						$playlist["items"][$tid]["max_width"] = sanitize_text_field($playlist["items"][$tid]["max_width"]);
					}

					if(isset($playlist["items"][$tid]["max_height"]) && strlen($playlist["items"][$tid]["max_height"]) >= 1){
						$playlist["items"][$tid]["max_height"] = sanitize_text_field($playlist["items"][$tid]["max_height"]);	
					}

					if(isset($playlist["items"][$tid]["subtitle"]) && strlen($playlist["items"][$tid]["subtitle"]) >= 1){
						$playlist["items"][$tid]["subtitle"] = esc_url_raw($playlist["items"][$tid]["subtitle"]);
					}

					if(isset($playlist["items"][$tid]["thumb"]) && strlen($playlist["items"][$tid]["thumb"]) >= 1){
						$playlist["items"][$tid]["thumb"] = esc_url_raw($playlist["items"][$tid]["thumb"]);	
					}

					if(isset($playlist["items"][$tid]["thumbnailsPreview"]) && strlen($playlist["items"][$tid]["thumbnailsPreview"]) >= 1){
						$playlist["items"][$tid]["thumbnailsPreview"] = sanitize_text_field($playlist["items"][$tid]["thumbnailsPreview"]);
					}

					if(isset($playlist["items"][$tid]["video_poster_source"]) && strlen($playlist["items"][$tid]["video_poster_source"]) >= 1){
						$playlist["items"][$tid]["video_poster_source"] = esc_url_raw($playlist["items"][$tid]["video_poster_source"]);
					}

					if(isset($playlist["items"][$tid]["vast"]) && strlen($playlist["items"][$tid]["vast"]) >= 1){
						$playlist["items"][$tid]["vast"] = esc_url_raw($playlist["items"][$tid]["vast"]);
					}

					if(isset($playlist["items"][$tid]["pass"]) && strlen($playlist["items"][$tid]["pass"]) >= 1){
						$playlist["items"][$tid]["pass"] = sanitize_text_field($playlist["items"][$tid]["pass"]);
					}	

				}

				$mainPlaylistsAr[$pid]["items"] = $playlist["items"];
			}

			$this->_data->main_playlists_ar = $mainPlaylistsAr;
			$this->_data->set_data();
			
			$msg = esc_html__('Your playlists have been updated!', 'fwdrl');
		}
	
        // Add and escape required js vars.
        $vars = 'var fwdMainPlaylistsAr = ' . '"' . esc_html(htmlspecialchars(json_encode($this->_data->main_playlists_ar))) . '";';
        $vars .= 'var fwdrlIconsPath = ' . '"' . esc_url_raw($this->_dir_url) . "content/icons/" . '";';
        $vars .= 'var fwdrlAddImage__ = ' . '"' . esc_html__('Add image', 'fwdrl') . '";';
        $vars .= 'var fwdrlChooseVTT__ = ' . '"' . esc_html__('Chose .vtt file', 'fwdrl') . '";';
        $vars .= 'var fwdrlAddVTT__ = ' . '"' . esc_html__('Add .vtt file', 'fwdrl') . '";';
        $vars .= 'var fwdrlChooseSubtitle__ = ' . '"' . esc_html__('Chose subtitle/.srt', 'fwdrl') . '";';
        $vars .= 'var fwdrlAddSubtitle__ = ' . '"' . esc_html__('Add subtitle/.srt', 'fwdrl') . '";';
        $vars .= 'var fwdrlChooseItem__ = ' . '"' . esc_html__('Choose item', 'fwdrl') . '";';
        $vars .= 'var fwdrlAddItem__ = ' . '"' . esc_html__('Add item', 'fwdrl') . '";';
        $vars .= 'var fwdrlChooseMultipleItems__ = ' . '"' . esc_html__('Choose multiple items', 'fwdrl') . '";';
        $vars .= 'var fwdrlChooseImage__ = ' . '"' . esc_html__('Chose image', 'fwdrl') . '";';
        $vars .= 'var fwdrlAddBulkItems__ = ' . '"' . esc_html__('Add bulk items', 'fwdrl') . '";';
        $vars .= 'var fwdrlDelete__ = ' . '"' . esc_html__('Delete', 'fwdrl') . '";';
        $vars .= 'var fwdrlEdit__ = ' . '"' . esc_html__('Edit', 'fwdrl') . '";';
        $vars .= 'var fwdrlAddNewGallery__ = ' . '"' . esc_html__('Add new gallery', 'fwdrl') . '";';
        $vars .= 'var fwdrlAddNewItem__ = ' . '"' . esc_html__('Add new item', 'fwdrl') . '";';
        $vars .= 'var fwdrlAdd__ = ' . '"' . esc_html__('Add', 'fwdrl') . '";';
        $vars .= 'var fwdrlUpdate__ = ' . '"' . esc_html__('Update', 'fwdrl') . '";';
        $vars .= 'var fwdrlCancel__ = ' . '"' . esc_html__('Cancel', 'fwdrl') . '";';
     	$vars .= 'var fwdrlYes__ = ' . '"' . esc_html__('Yes', 'fwdrl') . '";';
     	$vars .= 'var fwdrlNo__ = ' . '"' . esc_html__('No', 'fwdrl') . '";';

        wp_add_inline_script('fwdrl_playlist_manager_script', $vars);
    	include_once "playlist_manager.php";
    }
    

    // Update CSS file.
    public function set_css_editor(){
    	if (!$this->check_wp_ver()){
    		return;
    	}
    	
    	$msg = "";
    	$scroll_pos = 0;
    	
    	$css_file = plugin_dir_path(dirname(__FILE__)) . "css/fwdrl.css";
    	
	    if (!empty($_POST) && check_admin_referer("fwdrl_css_editor_update", "fwdrl_css_editor_nonce")){
			$handle = fopen($css_file, "w") or die("Cannot open file: " . $css_file);
			
			$data = str_replace("\\", "", $_POST["css_data"]);
			$data = str_replace("'e", "'\\e", $data);
			
			fwrite($handle, $data);
			
			$msg = __("The CSS file has been updated!", 'fwdrl');
		}
		
		$handle = fopen($css_file, "r") or die("Cannot open file: " . $css_file);
    	include_once "css_editor.php";
    	fclose($handle);
    }
    
	
	// Add RL constructor and/or galleries in the page where the shortcode is added.  
	public function set_rl($atts){
		
		extract(shortcode_atts(array( "gallery" => ''), $atts, "fwdrl"));
		
		$fwdrl_constructor = $this->get_constructor();
		$rl_main_playlist = $this->get_main_playlist($gallery);
		$rl_output =  $rl_main_playlist;

		wp_register_script( 'fwdrl-dummy-handle-footer', '', [], '', true );
   		wp_enqueue_script( 'fwdrl-dummy-handle-footer'  );
    	wp_add_inline_script( 'fwdrl-dummy-handle-footer', $fwdrl_constructor );
		
		return $rl_output; // All data has been escaped.
	}
	

	// Add shortcode metabox. 
	public function set_custom_meta_box($post){
		if (!$this->check_wp_ver()){
    		return;
    	}
		
		// Galleries.
		$mainPlaylistsNames = array();
		
		if (isset($this->_data->main_playlists_ar)){
			foreach ($this->_data->main_playlists_ar as $main_playlist){
	    		$el = array(
	    				"id" => $main_playlist["id"],
	    				"name" => $main_playlist["name"]
	    			);
	    				   
	    		array_push($mainPlaylistsNames, $el);
	    	}
		}
		
		// Add and escape required js vars.
		$vars = 'var fwdrlMainPlaylistsObj = ' . '"' . esc_html(htmlspecialchars(json_encode($mainPlaylistsNames))) . '";';
		
		wp_add_inline_script('fwdrl_shortcode_script', $vars);
    	include_once "meta_box.php";
	}
	

	// Get contructor. 
	public function get_constructor() {
    	$preset = $this->_data->settings_ar[0];
		$constructor = "";

		// Prepare share buttons.
		$shareButtons = preg_replace('/\s+/', '',$preset['shareButtons']);
		$shareLength = strlen($shareButtons);
		$shareButtons = explode(",", $shareButtons);

		$shareButtonsF = '';
		foreach($shareButtons as $key => $value) {
			$shareButtonsF .= "'" . $value . "',";
		}
		$shareButtonsF = mb_substr($shareButtonsF, 0, -1);
		if($shareLength < 2){
			$shareButtonsF = '';
		}
		
		/**
    	  *  Minified constructor to optimize page loading and also make sure it works
    	  *  in all themes, even those with wired plugins/code that tries to modify scripts
    	  *  and other unexpected bad code...
    	  */
		 
		$output = '';
    	if(!$this->is_Ligtbox_initialized){
			$output = "FWDRLUtils.onReady(function(){new FWDRL({instanceName:'rl0',mainFolderPath:'" . esc_url_raw($this->_dir_url) . "content',mediaSelector:'" . esc_html($preset['mediaSelector']) . "',useDeepLinking:" . ($preset['useDeepLinking']  == 'true' ? 'true' : 'false') .  ",useVectorIcons:" . ($preset['useVectorIcons'] == 'true' ? 'true' : 'false') . ",buttonsAlignment:'" . esc_html($preset['buttonsAlignment']) . "',mediaLazyLoading:" . ($preset['mediaLazyLoading']  == 'true' ? 'true' : 'false') . ",useDrag:" . ($preset['useDrag']  == 'true' ? 'true' : 'false') . ",useAsModal:" . ($preset['useAsModal'] == 'true' ? 'true' : 'false') . ",showSlideShowButton:" . ($preset['showSlideShowButton']  == 'true' ? 'true' : 'false') . ",showSlideShowAnimation:" . ($preset['showSlideShowAnimation']  == 'true' ? 'true' : 'false') . ",slideShowAutoPlay:" . ($preset['slideShowAutoPlay']  == 'true' ? 'true' : 'false') . ",slideShowAutoStop:" . ($preset['slideShowAutoStop']  == 'true' ? 'true' : 'false') . ",slideShowDelay:" . esc_html($preset['slideShowDelay']) . ",slideShowBkColor:'" . esc_html($preset['slideShowBkColor']) . "',slideShowFillColor:'" . esc_html($preset['slideShowFillColor']) . "',useKeyboard:" . ($preset['useKeyboard'] == 'true'  ? 'true' : 'false') . ",useDoubleClick:" . ($preset['useDoubleClick']  == 'true' ? 'true' : 'false') . ",showCloseButton:" . ($preset['showCloseButton']  == 'true' ? 'true' : 'false') . ",showAudioTracksButton:" . ($preset['showAudioTracksButton'] == 'true' ? 'true' : 'false')  . ",show360DegreeVideoVrButton:" . ($preset['show360DegreeVideoVrButton'] == 'true' ? 'true' : 'false') . ",rotationY360DegreeVideo:" . $preset['rotationY360DegreeVideo'] . ",showFullscreenButton:" . ($preset['showFullscreenButton']  == 'true' ? 'true' : 'false') . ",showZoomButton:" . ($preset['showZoomButton'] == 'true' ? 'true' : 'false') . ",showCounter:" . ($preset['showCounter'] == 'true' ? 'true' : 'false') . ",showNextAndPrevBtns:" . ($preset['showNextAndPrevBtns']  == 'true' ? 'true' : 'false') . ",hideButtonsOnDrag:" . ($preset['hideButtonsOnDrag']  == 'true' ? 'true' : 'false') . ",maxZoom:" . esc_html($preset['maxZoom']) . ",buttonsHideDelay:" . esc_html($preset['buttonsHideDelay']) . ",defaultItemWidth:" . esc_html($preset['defaultItemWidth']) . ",defaultItemHeight:" . esc_html($preset['defaultItemHeight']) . ",itemOffsetHeightButtonsTop:" . esc_html($preset['itemOffsetHeightButtonsTop']) . ",spaceBetweenBtns:" . esc_html($preset['spaceBetweenBtns']) . ",buttonsOffsetIn:" . esc_html($preset['buttonsOffsetIn']) . ",buttonsOffsetOut:" . esc_html($preset['buttonsOffsetOut']) . ",itemBorderSize:" . esc_html($preset['itemBorderSize']) . ",itemBackgroundColor:'" . esc_html($preset['itemBackgroundColor']) . "',itemBorderColor:'" . esc_html($preset['itemBorderColor']) . "',preloaderBkColor:'" . esc_html($preset['preloaderBkColor']) . "',preloaderFillColor:'" . esc_html($preset['preloaderFillColor']) . "',backgroundColor:'" . esc_html($preset['backgroundColor']) . "',rightClickContextMenu:'" . esc_html($preset['rightClickContextMenu']) . "',shareButtons:[" .  wp_kses_post($shareButtonsF) . "],shareText:'" . esc_html($preset['shareText']) . "',sharedURL:'" . esc_html($preset['sharedURL']) . "',shareMainBackgroundColor:'" . esc_html($preset['shareMainBackgroundColor']) . "',shareBackgroundColor:'" . esc_html($preset['shareBackgroundColor']) . "',showThumbnails:" . ($preset['showThumbnails']  == 'true' ? 'true' : 'false') . ",showThumbnailsIcon:" . ($preset['showThumbnailsIcon'] == 'true' ? 'true' : 'false') . ",thumbnailsHeight:" . esc_html($preset['thumbnailsHeight']) . ",thumbnailsOverlayColor:'" . esc_html($preset['thumbnailsOverlayColor']) . "',thumbnailsBorderSize:" . esc_html($preset['thumbnailsBorderSize']) . ",thumbnailsBorderColor:'" .esc_html( $preset['thumbnailsBorderColor']) . "',spaceBetweenThumbnailsAndItem:" . esc_html($preset['spaceBetweenThumbnailsAndItem']) . ",spaceBetweenThumbnails:" . esc_html($preset['spaceBetweenThumbnails']) . ",caption:" . ($preset['caption'] == 'true' ? 'true' : 'false') . ",captionPosition:'" . esc_html($preset['captionPosition']) . "',showCaptionOnSmallScreens:" . ($preset['showCaptionOnSmallScreens'] == 'true' ? 'true' : 'false') . ",animateCaption:" . ($preset['animateCaption'] == 'true' ? 'true' : 'false') . ",captionAnimationType:'" . esc_html($preset['captionAnimationType']) . "',useVideo:" . ($preset['useVideo'] == 'true' ? 'true' : 'false') . ",fillEntireScreenWithPoster:" . ($preset['fillEntireScreenWithPoster'] == 'true' ? 'true' : 'false') . ",volume:" . $preset['volume'] . ",videoAutoPlay:" . ($preset['videoAutoPlay'] == 'true' ? 'true' : 'false') . ",nextVideoAutoPlay:" . ($preset['nextVideoAutoPlay'] == 'true' ? 'true' : 'false') . ",videoAutoPlayText:'" . esc_html($preset['videoAutoPlayText']) . "',showLogo:" . ($preset['showLogo'] == 'true' ? 'true' : 'false') . ",logoPath:'" . esc_url($preset['logoPath']) . "',logoLink:'" . esc_url_raw($preset['logoLink']) . "',showControllerWhenVideoIsStopped:" . ($preset['showControllerWhenVideoIsStopped'] == 'true' ? 'true' : 'false') . ",showDefaultControllerForVimeo:" . ($preset['showDefaultControllerForVimeo'] == 'true' ? 'true' : 'false') . ",showScrubberWhenControllerIsHidden:" . ($preset['showScrubberWhenControllerIsHidden'] == 'true' ? 'true' : 'false') . ",showRewindButton:" . ($preset['showRewindButton'] == 'true' ? 'true' : 'false') . ",showVolumeButton:" . ($preset['showVolumeButton'] == 'true' ? 'true' : 'false') . ",showTime:" . ($preset['showTime'] == 'true' ? 'true' : 'false') . ",timeColor:'" . esc_html($preset['timeColor']) . "',showChromecastButton:" . ($preset['showChromecastButton'] == 'true' ? 'true' : 'false') . ",showPlaybackRateButton:" . ($preset['showPlaybackRateButton'] == 'true' ? 'true' : 'false') . ",showQualityButton:" . ($preset['showQualityButton'] == 'true' ? 'true' : 'false') . ",showFullScreenButton:" . ($preset['showFullScreenButton'] == 'true'? 'true' : 'false') . ",showScrubberToolTipLabel:" . ($preset['showScrubberToolTipLabel'] == 'true' ? 'true' : 'false') . ",youtubeQualityButtonNormalColor:'" . esc_html($preset['youtubeQualityButtonNormalColor']) . "',youtubeQualityButtonSelectedColor:'" . esc_html($preset['youtubeQualityButtonSelectedColor']) . "',scrubbersToolTipLabelBackgroundColor:'" . esc_html($preset['scrubbersToolTipLabelBackgroundColor']) . "',scrubbersToolTipLabelFontColor:'" . esc_html($preset['scrubbersToolTipLabelFontColor']) . "',audioVisualizerLinesColor:'" . esc_html($preset['audioVisualizerLinesColor']) . "',audioVisualizerCircleColor:'" . esc_html($preset['audioVisualizerCircleColor']) . "',thumbnailsPreviewWidth:" . esc_html($preset['thumbnailsPreviewWidth']) . ",thumbnailsPreviewBackgroundColor:'" . esc_html($preset['thumbnailsPreviewBackgroundColor']) . "',thumbnailsPreviewLabelBackgroundColor:'" . esc_html($preset['thumbnailsPreviewLabelBackgroundColor']) . "',thumbnailsPreviewLabelFontColor:'" . esc_html($preset['thumbnailsPreviewLabelFontColor']) . "',skipToVideoText:'" . esc_html($preset['skipToVideoText']) . "',skipToVideoButtonText:'" . esc_html($preset['skipToVideoButtonText']) . "'});});";
		}
	
		$this->is_Ligtbox_initialized = true;
		return $output;
    }
    

    // Get main playlist. 
    public function get_main_playlist($playlistId){
    	$main_playlist = NULL;
    	
    	if($playlistId == 'static'){
    		return '';
    	}
    	
    	foreach ($this->_data->main_playlists_ar as $pl){
    		if ($pl["name"] == $playlistId){
    			$main_playlist = $pl;
    		}
    	}
		
    	if(is_null($main_playlist)){
    		return "Revolution Lightbox gallery with id <strong>". esc_html($playlistId) . "</strong> does not exist!";
    	}
		
		// Added display none here to make sure this is hidden!
		$main_playlist_str = '<ul id="' . esc_html($playlistId) . '" class="fwdrl-gallery">';
		
		foreach ($main_playlist['items'] as $item){
			
			$main_playlist_str .= '<li data-src="' . esc_url_raw($item["source"]) . '"';
			
			if(isset($item["thumb"]) && strlen($item["thumb"]) >= 1){
				$main_playlist_str .= ' data-thumb="' . esc_url_raw($item["thumb"]) . '"';
			}
			
			if(isset($item["video_poster_source"]) && strlen($item["video_poster_source"]) >= 1){
				$main_playlist_str .= ' data-poster="' . esc_url_raw($item["video_poster_source"]) . '"';
			}
			
			if(isset($item["max_width"]) && strlen($item["max_width"]) >= 1){
				$main_playlist_str .= ' data-width="' . esc_html($item["max_width"]) . '"';
			}
			
			if(isset($item["max_height"]) && strlen($item["max_height"]) >= 1){
				$main_playlist_str .= ' data-height="' . esc_html($item["max_height"]) . '"';
			}

			if(isset($item["subtitle"]) && strlen($item["subtitle"]) >= 1){
				$main_playlist_str .= ' data-subtitle="' . esc_url_raw($item["subtitle"]) . '"';
			}

			if(isset($item["thumbnailsPreview"]) && strlen($item["thumbnailsPreview"]) >= 1){
				$main_playlist_str .= ' data-thumbnails-preview="' . wp_kses_post($item["thumbnailsPreview"]) . '"';
			}
			
			if(isset($item["vast"]) && strlen($item["vast"]) >= 1){
				$main_playlist_str .= ' data-vast="' . esc_url_raw($item["vast"]) . '"';
			}

			if(isset($item["pass"]) && strlen($item["pass"]) >= 1){
				$main_playlist_str .= ' data-password="' . esc_html(md5($item["pass"])) . '"';
			}
			
			if(isset($item["is360"]) && $item["is360"] == 'yes'){
				$main_playlist_str .= ' data-is-360=""';
			}

			$main_playlist_str .= ">";
			
			if(isset($item["dsecription"]) && strlen($item["dsecription"]) >= 1){
				$main_playlist_str .= wp_kses_post($item["dsecription"]);
			}
			
			$main_playlist_str .=  '</li>';
		}
		
		$main_playlist_str .=  '</ul>';
		
    	return $main_playlist_str; // All data has been escaped.
    }

    // Clean function for names/labels.
	private function clean_name($string) {
		$string = preg_replace('/"/', '\'', $string);
	   	return preg_replace('/[\%\^\$\#\'\[\]\&\/<>|\\\\]/', '', $string);
	}

	private function clean_name_2($string) {
		$string = preg_replace('/"/', '\'', $string);
	   	return preg_replace('/[\[\]\&\/<>|\\\\]/', '', $string);
	}
}

?>